@@ -428,6 +428,7 @@ class AnalyzeSwaggerClientWrapper:
         model_validation_method: dto.ModelValidationMethod = dto.ModelValidationMethod.FIVE_FOLD_CROSS,
         no_mixing_columns: Optional[List[str]] = None,
         data_partition_method: dto.DataPartitionMethod = dto.DataPartitionMethod.RANDOM,
+        hold_out_percentage: Optional[float] = 10.0,
         partition_column: Optional[str] = None,
         order_by_column: Optional[str] = None,
         weight_column: Optional[str] = None,
@@ -446,6 +447,7 @@ class AnalyzeSwaggerClientWrapper:
             excluded_columns=excluded_columns or UNSET,
             nlp_language=nlp_language,
             draft_mode=draft_mode,
+            hold_out_percentage=hold_out_percentage or UNSET,
             no_mixing_columns=no_mixing_columns or UNSET,
             partition_column=partition_column or UNSET,
             order_by_column=order_by_column or UNSET,
@@ -468,6 +470,7 @@ class AnalyzeSwaggerClientWrapper:
         name: str,
         data_set_id: int,
         target_column: str,
+        target_distribution: Optional[dto.TargetDistributions] = None,
         score_to_optimize: dto.RegressionScorers = dto.RegressionScorers.RMSE,
         excluded_columns: Optional[List[str]] = None,
         description: Optional[str] = None,
@@ -477,6 +480,7 @@ class AnalyzeSwaggerClientWrapper:
         model_validation_method: dto.ModelValidationMethod = dto.ModelValidationMethod.FIVE_FOLD_CROSS,
         no_mixing_columns: Optional[List[str]] = None,
         data_partition_method: dto.DataPartitionMethod = dto.DataPartitionMethod.RANDOM,
+        hold_out_percentage: Optional[float] = 10.0,
         partition_column: Optional[str] = None,
         order_by_column: Optional[str] = None,
         weight_column: Optional[str] = None,
@@ -487,6 +491,7 @@ class AnalyzeSwaggerClientWrapper:
             name=name,
             data_set_id=data_set_id,
             target_column=target_column,
+            target_distribution=target_distribution or UNSET,
             score_to_optimize=score_to_optimize,
             model_validation_method=model_validation_method,
             data_partition_method=data_partition_method,
@@ -495,6 +500,7 @@ class AnalyzeSwaggerClientWrapper:
             excluded_columns=excluded_columns or UNSET,
             nlp_language=nlp_language,
             draft_mode=draft_mode,
+            hold_out_percentage=hold_out_percentage or UNSET,
             no_mixing_columns=no_mixing_columns or UNSET,
             partition_column=partition_column or UNSET,
             order_by_column=order_by_column or UNSET,
