@@ -38,6 +38,7 @@ class AnalyzeModel(abc.ABC):
         sample_weight: Optional[str] = None,
         order_by: Optional[str] = None,
         partition_by: Optional[str] = None,
+        hold_out_percentage: Optional[float] = 10.0,
         no_mixing: Optional[List[str]] = None,
     ) -> "AnalyzeModel":
         """Internal method - DO NOT USE"""
@@ -50,6 +51,7 @@ class AnalyzeModel(abc.ABC):
             partition_by=partition_by,
             no_mixing=no_mixing,
             sample_weight=sample_weight,
+            hold_out_percentage=hold_out_percentage,
         )
         if wait_until_complete:
             self._internal_model.wait_until_fitted()
