@@ -1,9 +1,11 @@
 import abc
 from typing import List, Optional
 
+import pandas as pd
+
 from ....swagger.models import ModelResponse
 from ....utils.typing import PathLike
-from ...data_set import DataLike
+from ...data_set import DataLike, DataSet
 from ...prediction import Prediction
 from ...test import Test
 
@@ -17,8 +19,10 @@ class BaseModel(abc.ABC):
         excluded_columns: Optional[List[str]] = None,
         *,
         # Classification and Regression specific fit parameters
+        sample_weight: Optional[str] = None,
         order_by: Optional[str] = None,
         partition_by: Optional[str] = None,
+        hold_out_percentage: Optional[float] = 10.0,
         no_mixing: Optional[List[str]] = None,
     ) -> "BaseModel":
         """Fit the model and return a fitted version"""
@@ -77,3 +81,15 @@ class BaseModel(abc.ABC):
     @abc.abstractmethod
     def wait_until_fitted(self):
         """Wait for the model to finish and return whether the fitting was successful"""
+
+    @abc.abstractmethod
+    def results_as_df(self) -> pd.DataFrame:
+        """A data frame containing the model results data. For classification & regression this result is the result of hold-out
+        test, for clustering it is the clustered data."""
+
+    @abc.abstractmethod
+    def save_results_as_dataset(
+        self, *, name: Optional[str] = None, description: Optional[str] = None
+    ) -> DataSet:
+        """Save the model results data as a data set to allow use in other places in the system - For classification & regression
+        this result is the result of hold-out test, for clustering it is the clustered data."""
