@@ -1,5 +1,7 @@
 """ Contains all the data models used in inputs/outputs """
 
+from .api_column_level import ApiColumnLevel
+from .api_column_type import ApiColumnType
 from .api_history_response import ApiHistoryResponse
 from .apply_data_prep_steps_request import ApplyDataPrepStepsRequest
 from .apply_formula_step import ApplyFormulaStep
@@ -42,6 +44,7 @@ from .data_pipeline_create_request import DataPipelineCreateRequest
 from .data_pipeline_response import DataPipelineResponse
 from .data_pipelines_response import DataPipelinesResponse
 from .data_prep_step_response import DataPrepStepResponse
+from .data_set_column_metadata_response import DataSetColumnMetadataResponse
 from .data_set_response import DataSetResponse
 from .data_sets_response import DataSetsResponse
 from .decisioning_decision import DecisioningDecision
@@ -133,6 +136,7 @@ from .simplify_categories_step_step_type import SimplifyCategoriesStepStepType
 from .split_column_step import SplitColumnStep
 from .split_column_step_step_type import SplitColumnStepStepType
 from .status import Status
+from .target_distributions import TargetDistributions
 from .test_list_response import TestListResponse
 from .test_response import TestResponse
 from .test_response_problem_type import TestResponseProblemType
