@@ -7,6 +7,7 @@ from ..models.model_validation_method import ModelValidationMethod
 from ..models.nlp_language import NlpLanguage
 from ..models.regression_model_type import RegressionModelType
 from ..models.regression_scorers import RegressionScorers
+from ..models.target_distributions import TargetDistributions
 from ..types import UNSET, Unset
 
 T = TypeVar("T", bound="CreateRegressionRequest")
@@ -23,9 +24,11 @@ class CreateRegressionRequest:
         data_partition_method (DataPartitionMethod):
         number_of_evaluations (int):
         description (Union[Unset, str]):
+        target_distribution (Union[Unset, TargetDistributions]):  Default: TargetDistributions.GAUSSIAN.
         excluded_columns (Union[Unset, List[str]]):
         nlp_language (Union[Unset, NlpLanguage]):  Default: NlpLanguage.AUTO_DETECT.
         draft_mode (Union[Unset, bool]):
+        hold_out_percentage (Union[Unset, float]):  Default: 10.0.
         no_mixing_columns (Union[Unset, List[str]]):
         partition_column (Union[Unset, str]):
         order_by_column (Union[Unset, str]):
@@ -41,9 +44,11 @@ class CreateRegressionRequest:
     data_partition_method: DataPartitionMethod
     number_of_evaluations: int
     description: Union[Unset, str] = UNSET
+    target_distribution: Union[Unset, TargetDistributions] = TargetDistributions.GAUSSIAN
     excluded_columns: Union[Unset, List[str]] = UNSET
     nlp_language: Union[Unset, NlpLanguage] = NlpLanguage.AUTO_DETECT
     draft_mode: Union[Unset, bool] = UNSET
+    hold_out_percentage: Union[Unset, float] = 10.0
     no_mixing_columns: Union[Unset, List[str]] = UNSET
     partition_column: Union[Unset, str] = UNSET
     order_by_column: Union[Unset, str] = UNSET
@@ -64,6 +69,10 @@ class CreateRegressionRequest:
 
         number_of_evaluations = self.number_of_evaluations
         description = self.description
+        target_distribution: Union[Unset, str] = UNSET
+        if not isinstance(self.target_distribution, Unset):
+            target_distribution = self.target_distribution.value
+
         excluded_columns: Union[Unset, List[str]] = UNSET
         if not isinstance(self.excluded_columns, Unset):
             excluded_columns = self.excluded_columns
@@ -76,6 +85,7 @@ class CreateRegressionRequest:
             nlp_language = self.nlp_language.value
 
         draft_mode = self.draft_mode
+        hold_out_percentage = self.hold_out_percentage
         no_mixing_columns: Union[Unset, List[str]] = UNSET
         if not isinstance(self.no_mixing_columns, Unset):
             no_mixing_columns = self.no_mixing_columns
@@ -111,12 +121,16 @@ class CreateRegressionRequest:
         })
         if description is not UNSET:
             field_dict["description"] = description
+        if target_distribution is not UNSET:
+            field_dict["targetDistribution"] = target_distribution
         if excluded_columns is not UNSET:
             field_dict["excludedColumns"] = excluded_columns
         if nlp_language is not UNSET:
             field_dict["nlpLanguage"] = nlp_language
         if draft_mode is not UNSET:
             field_dict["draftMode"] = draft_mode
+        if hold_out_percentage is not UNSET:
+            field_dict["holdOutPercentage"] = hold_out_percentage
         if no_mixing_columns is not UNSET:
             field_dict["noMixingColumns"] = no_mixing_columns
         if partition_column is not UNSET:
@@ -160,6 +174,16 @@ class CreateRegressionRequest:
 
         description = d.pop("description", UNSET)
 
+        _target_distribution = d.pop("targetDistribution", UNSET)
+        target_distribution: Union[Unset, TargetDistributions]
+        if isinstance(_target_distribution,  Unset):
+            target_distribution = UNSET
+        else:
+            target_distribution = TargetDistributions(_target_distribution)
+
+
+
+
         excluded_columns = cast(List[str], d.pop("excludedColumns", UNSET))
 
 
@@ -175,6 +199,8 @@ class CreateRegressionRequest:
 
         draft_mode = d.pop("draftMode", UNSET)
 
+        hold_out_percentage = d.pop("holdOutPercentage", UNSET)
+
         no_mixing_columns = cast(List[str], d.pop("noMixingColumns", UNSET))
 
 
@@ -203,9 +229,11 @@ class CreateRegressionRequest:
             data_partition_method=data_partition_method,
             number_of_evaluations=number_of_evaluations,
             description=description,
+            target_distribution=target_distribution,
             excluded_columns=excluded_columns,
             nlp_language=nlp_language,
             draft_mode=draft_mode,
+            hold_out_percentage=hold_out_percentage,
             no_mixing_columns=no_mixing_columns,
             partition_column=partition_column,
             order_by_column=order_by_column,
