@@ -41,7 +41,7 @@ class ModelResponse:
         influences (Union[Unset, None, List[ModelInfluence]]):
         create_config (Union[CreateAutoClusteringRequest, CreateClassificationRequest, CreateClusteringRequest,
             CreateDecisioningRequest, CreateForecastingRequest, CreateMultiForecastingRequest, CreateRegressionRequest,
-            NullRequest, Unset]):
+            None, NullRequest, Unset]):
         create_endpoint (Union[Unset, str]):
     """
 
@@ -59,7 +59,7 @@ class ModelResponse:
     health: Union[Unset, None, ModelHealth] = UNSET
     score: Union[Unset, None, ModelScore] = UNSET
     influences: Union[Unset, None, List[ModelInfluence]] = UNSET
-    create_config: Union[CreateAutoClusteringRequest, CreateClassificationRequest, CreateClusteringRequest, CreateDecisioningRequest, CreateForecastingRequest, CreateMultiForecastingRequest, CreateRegressionRequest, NullRequest, Unset] = UNSET
+    create_config: Union[CreateAutoClusteringRequest, CreateClassificationRequest, CreateClusteringRequest, CreateDecisioningRequest, CreateForecastingRequest, CreateMultiForecastingRequest, CreateRegressionRequest, None, NullRequest, Unset] = UNSET
     create_endpoint: Union[Unset, str] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
@@ -101,9 +101,11 @@ class ModelResponse:
 
 
 
-        create_config: Union[Dict[str, Any], Unset]
+        create_config: Union[Dict[str, Any], None, Unset]
         if isinstance(self.create_config, Unset):
             create_config = UNSET
+        elif self.create_config is None:
+            create_config = None
 
         elif isinstance(self.create_config, CreateAutoClusteringRequest):
             create_config = UNSET
@@ -250,7 +252,9 @@ class ModelResponse:
             influences.append(influences_item)
 
 
-        def _parse_create_config(data: object) -> Union[CreateAutoClusteringRequest, CreateClassificationRequest, CreateClusteringRequest, CreateDecisioningRequest, CreateForecastingRequest, CreateMultiForecastingRequest, CreateRegressionRequest, NullRequest, Unset]:
+        def _parse_create_config(data: object) -> Union[CreateAutoClusteringRequest, CreateClassificationRequest, CreateClusteringRequest, CreateDecisioningRequest, CreateForecastingRequest, CreateMultiForecastingRequest, CreateRegressionRequest, None, NullRequest, Unset]:
+            if data is None:
+                return data
             if isinstance(data, Unset):
                 return data
             try:
