@@ -8,6 +8,9 @@ class RegressionModelType(str, Enum):
     GRADIENT_BOOST_REGRESSOR = "GRADIENT_BOOST_REGRESSOR"
     K_NEIGHBOURS_REGRESSOR = "K_NEIGHBOURS_REGRESSOR"
     LINEAR_SVM_REGRESSOR = "LINEAR_SVM_REGRESSOR"
+    GLM_REGRESSOR = "GLM_REGRESSOR"
+    XGB_REGRESSOR = "XGB_REGRESSOR"
+    HIST_GRAD_BOOST_REGRESSOR = "HIST_GRAD_BOOST_REGRESSOR"
 
     def __str__(self) -> str:
         return str(self.value)
\ No newline at end of file
