@@ -5,6 +5,8 @@ class RegressionScorers(str, Enum):
     RMSE = "RMSE"
     ABSOLUTE_ERROR = "ABSOLUTE_ERROR"
     R2 = "R2"
+    LOG_LIKELIHOOD = "LOG_LIKELIHOOD"
+    GINI = "GINI"
 
     def __str__(self) -> str:
         return str(self.value)
\ No newline at end of file
