@@ -2,7 +2,7 @@ from enum import Enum
 
 
 class TransformTextStepIfNoMatch(str, Enum):
-    PASS_ = "pass"
+    PASS = "pass"
     BLANK = "blank"
 
     def __str__(self) -> str:
