@@ -1,14 +1,5 @@
 """ Contains some shared types for properties """
-from typing import (
-    BinaryIO,
-    Generic,
-    MutableMapping,
-    Optional,
-    TextIO,
-    Tuple,
-    TypeVar,
-    Union,
-)
+from typing import BinaryIO, Generic, MutableMapping, Optional, Tuple, TypeVar
 
 import attr
 
@@ -20,16 +11,18 @@ class Unset:
 
 UNSET: Unset = Unset()
 
+FileJsonType = Tuple[Optional[str], BinaryIO, Optional[str]]
+
 
 @attr.s(auto_attribs=True)
 class File:
     """ Contains information for file uploads """
 
-    payload: Union[BinaryIO, TextIO]
+    payload: BinaryIO
     file_name: Optional[str] = None
     mime_type: Optional[str] = None
 
-    def to_tuple(self) -> Tuple[Optional[str], Union[BinaryIO, TextIO], Optional[str]]:
+    def to_tuple(self) -> FileJsonType:
         """ Return a tuple representation that httpx will accept for multipart/form-data """
         return self.file_name, self.payload, self.mime_type
 
@@ -47,4 +40,4 @@ class Response(Generic[T]):
     parsed: Optional[T]
 
 
-__all__ = ["File", "Response"]
\ No newline at end of file
+__all__ = ["File", "Response", "FileJsonType"]
\ No newline at end of file
